<?php

namespace JetBackup\Settings;

use JetBackup\Exception\IOException;
use ReflectionException;

if (!defined( '__JETBACKUP__')) die('Direct access is not allowed');

class Restore extends Settings {

	const SECTION = 'restore';
	
	const RESTORE_COMPATIBILITY_CHECK = 'RESTORE_COMPATIBILITY_CHECK';
	const RESTORE_ALLOW_CROSS_DOMAIN = 'RESTORE_ALLOW_CROSS_DOMAIN';


	/**
	 * @throws IOException
	 * @throws ReflectionException
	 */
	public function __construct() {
		parent::__construct(self::SECTION);
	}

	/**
	 * @return bool
	 */
	public function isRestoreCompatibilityCheckEnabled():bool { return (bool) $this->get(self::RESTORE_COMPATIBILITY_CHECK, true); }
	public function isRestoreAllowCrossDomain():bool { return (bool) $this->get(self::RESTORE_ALLOW_CROSS_DOMAIN, false); }

	/**
	 * @param bool $value
	 *
	 * @return void
	 */
	public function setRestoreCompatibilityCheck(bool $value):void { $this->set(self::RESTORE_COMPATIBILITY_CHECK, $value); }

	public function setRestoreAllowCrossDomain(bool $value):void { $this->set(self::RESTORE_ALLOW_CROSS_DOMAIN, $value); }

	/**
	 * @return bool[]
	 */
	public function getDisplay():array {

		return [
			self::RESTORE_COMPATIBILITY_CHECK   => $this->isRestoreCompatibilityCheckEnabled() ? 1 : 0,
			self::RESTORE_ALLOW_CROSS_DOMAIN   => $this->isRestoreAllowCrossDomain() ? 1 : 0,
		];
	}

	/**
	 * @return bool[]
	 */
	public function getDisplayCLI():array {

		return [
			'Restore Compatability Check'   => $this->isRestoreCompatibilityCheckEnabled(),
			'Restore Allow Cross Domain'   => $this->isRestoreAllowCrossDomain(),
		];
	}

	/**
	 * @return void
	 */
	public function validateFields():void {
	}
}